@@ -1,6 +1,6 @@
 use std::ops::Range;
 
-use super::{DescreteRanged, Ranged};
+use super::{AsRangedCoord, DescreteRanged, Ranged};
 
 macro_rules! impl_descrete_trait {
     ($name:ident) => {
@@ -12,6 +12,15 @@ macro_rules! impl_descrete_trait {
     };
 }
 
+macro_rules! impl_ranged_type_trait {
+    ($value:ty, $coord:ident) => {
+        impl AsRangedCoord for Range<$value> {
+            type CoordDescType = $coord;
+            type Value = $value;
+        }
+    };
+}
+
 macro_rules! make_numeric_coord {
     ($type:ty, $name:ident, $key_points:ident) => {
         pub struct $name($type, $type);
@@ -30,7 +39,7 @@ macro_rules! make_numeric_coord {
                     return limit.1;
                 }
 
-                return limit.0 + (actual_length as f64 * logic_length) as i32;
+                return limit.0 + (actual_length as f64 * logic_length + 1e-3).floor() as i32;
             }
             fn key_points(&self, max_points: usize) -> Vec<$type> {
                 $key_points((self.0, self.1), max_points)
@@ -80,7 +89,7 @@ macro_rules! gen_key_points_comp {
             let right = range.1 - rem_euclid(range.1, scale);
             while left <= right {
                 let size = (10f64).powf(digits as f64);
-                left = (left * size).round() / size;
+                left = (left * size + 1e-3).round() / size;
                 ret.push(left as $type);
                 left += scale;
             }
@@ -139,6 +148,13 @@ impl_descrete_trait!(RangedCoordi32);
 impl_descrete_trait!(RangedCoordu64);
 impl_descrete_trait!(RangedCoordi64);
 
+impl_ranged_type_trait!(f32, RangedCoordf32);
+impl_ranged_type_trait!(f64, RangedCoordf64);
+impl_ranged_type_trait!(i32, RangedCoordi32);
+impl_ranged_type_trait!(i64, RangedCoordi64);
+impl_ranged_type_trait!(u32, RangedCoordu32);
+impl_ranged_type_trait!(u64, RangedCoordu64);
+
 /*
 pub fn keypoints_i64(range:(i64,i64), n:usize) -> Vec<i64> {
     compute_i64_key_points(range,n)
