@@ -12,7 +12,7 @@
 
 
 
-Plotters is a flexible drawing library for data visualization written in pure Rust.
+Plotters is a flexible drawing library for data visualization written in pure Rust for both native and WebAssembly.
 
 - Why plotting in Rust?
 Although rendering a figure doesn't requires too many computation power in most of the case,
@@ -27,6 +27,11 @@ Currently, we support line series, point series and candlestick series.
 And the library is designed to be able to render multiple figure into a single image.
 But Plotter is aimed to be a platform that is fully extendable to supporting any other types of figure.
 
+- Plotting on HTML5 canvas
+Plotters currently supports backend that uses the HTML5 canvas. To use the WASM support, you can simply create
+`CanvasBackend` instead of other backend and all other API remains the same!
+Check the demo that uses Plotters with WASM at [here](http://home.chpc.utah.edu/~u0875014/wasm-test/)
+
 
 ## Gallery
 
@@ -55,7 +60,7 @@ But Plotter is aimed to be a platform that is fully extendable to supporting any
         <img src="https://raw.githubusercontent.com/38/plotters/master/examples/outputs/histogram.png" class="galleryItem"></img>
     </a>
     <div class="galleryText">
-       Histogram 
+       Histogram
         <a href="https://github.com/38/plotters/blob/master/examples/histogram.rs">[code]</a>
     </div>
 </div>
@@ -77,13 +82,13 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     let mut backend = BitMapBackend::new("examples/outputs/0.png", (640, 480));
     backend.open()?;
     let root: DrawingArea<_, _> = backend.into();
-    let font = Into::<FontDesc>::into("Arial").resize(20.0);
-    root.fill(&RGBColor(255, 255, 255))?;
+    let font = Into::<FontDesc>::into("Arial").resize(50.0);
+    root.fill(&White)?;
     let mut chart = ChartBuilder::on(&root)
         .caption("y=x^2", &font)
-        .set_x_label_size(30)
-        .set_y_label_size(30)
-        .build_ranged::<RangedCoordf32, RangedCoordf32, _, _>(-1f32..1f32, -0.1f32..1f32);
+        .x_label_area_size(30)
+        .y_label_area_size(30)
+        .build_ranged(-1f32..1f32, -0.1f32..1f32);
 
     chart.configure_mesh().draw()?;
 
@@ -113,7 +118,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     // And if we want SVG backend
     // let backend = SVGBackend::new("output.svg", (800, 600));
     backend.open()?;
-    backend.draw_rect((50,50), (200, 150), &RGBColor(255,0,0), true)?;
+    backend.draw_rect((50,50), (200, 150), &Red, true)?;
     backend.close()?;
     return Ok(());
 }
@@ -164,9 +169,9 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
     let backend = BitMapBackend::new("examples/outputs/3.png", (300, 200));
     // A backend object can be converted into a drawing area
     let root:DrawingArea<_,_> = backend.into();
-    root.fill(&RGBColor(255,255,255));
+    root.fill(&White);
     // Draw an circle on the drawing area
-    root.draw(&Circle::new((100,100), 50, Into::<ShapeStyle>::into(&RGBColor(0, 255, 0)).filled()))?;
+    root.draw(&Circle::new((100,100), 50, Into::<ShapeStyle>::into(&Green).filled()))?;
     root.close()?;
     return Ok(());
 }
@@ -198,7 +203,7 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 
     let dot_and_label = |x:f32,y:f32| {
         return EmptyElement::at((x,y))
-               + Circle::new((0,0), 3, Into::<ShapeStyle>::into(&RGBColor(0,0,0)).filled())
+               + Circle::new((0,0), 3, ShapeStyle::from(&Black).filled())
                + OwnedText::new(format!("({:.2},{:.2})", x, y), (10, 0), &font);
     };
 
@@ -224,7 +229,7 @@ use plotters::prelude::*;
 fn main() -> Result<(), Box<dyn std::error::Error>> {
     let backend = BitMapBackend::new("examples/outputs/5.png", (640, 480));
     let root:DrawingArea<_,_> = backend.into();
-    root.fill(&RGBColor(255,255,255));
+    root.fill(&White);
     let root = root.margin(10,10,10,10);
     // After this point, we should be able to draw construct a chart context
     let font:FontDesc = Into::<FontDesc>::into("Arial").resize(40.0);
@@ -233,10 +238,10 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
         // Set the caption of the chart
         .caption("This is our first plot", &font)
         // Set the size of the label region
-        .set_x_label_size(40)
-        .set_y_label_size(40)
+        .x_label_area_size(20)
+        .y_label_area_size(40)
         // Finally attach a coordinate on the drawing area and make a chart context
-        .build_ranged::<RangedCoordf32, RangedCoordf32, _, _>(0f32..10f32, 0f32..10f32);
+        .build_ranged(0f32..10f32, 0f32..10f32);
 
     // Then we can draw a mesh
     chart.configure_mesh()
@@ -249,9 +254,9 @@ fn main() -> Result<(), Box<dyn std::error::Error>> {
 
     // And we can draw something in the drawing area
     let smaller_font = font.resize(10.0);
-    chart.draw_series(LineSeries::new(vec![(0.0,0.0), (5.0, 5.0), (8.0, 7.0)], &RGBColor(255,0,0)))?;
+    chart.draw_series(LineSeries::new(vec![(0.0,0.0), (5.0, 5.0), (8.0, 7.0)], &Red))?;
     // Similarly, we can draw point series
-    chart.draw_series(PointSeries::of_element(vec![(0.0,0.0), (5.0, 5.0), (8.0, 7.0)], 5, &RGBColor(255,0,0), &|c,s,st| {
+    chart.draw_series(PointSeries::of_element(vec![(0.0,0.0), (5.0, 5.0), (8.0, 7.0)], 5, &Red, &|c,s,st| {
         return EmptyElement::at(c)    // We want to construct a composed element on-the-fly
             + Circle::new((0,0),s,st.filled()) // At this point, the new pixel coordinate is established
             + OwnedText::new(format!("{:?}", c), (10, 0), &smaller_font);
@@ -296,15 +301,14 @@ pub mod prelude {
         CoordTranslate, Ranged, RangedCoord, RangedCoordf32, RangedCoordf64, RangedCoordi32,
         RangedCoordi64, RangedCoordu32, RangedCoordu64, RangedDate, RangedDateTime,
     };
-    pub use crate::drawing::{backend::DrawingBackend, DrawingArea};
+    pub use crate::drawing::*;
     pub use crate::series::{Histogram, LineSeries, PointSeries};
     pub use crate::style::{
-        Color, FontDesc, Mixable, Palette, Palette100, Palette99, Palette9999, RGBColor,
-        ShapeStyle, TextStyle,
+        Black, Blue, Color, Cyan, FontDesc, Green, Magenta, Mixable, Palette, Palette100,
+        Palette99, Palette9999, PaletteColor, RGBColor, Red, ShapeStyle, SimpleColor, TextStyle,
+        Transparent, White, Yellow,
     };
 
-    pub use crate::drawing::{BitMapBackend, SVGBackend};
-
     pub use crate::element::{
         CandleStick, Circle, Cross, EmptyElement, OwnedText, Path, Rectangle, Text,
     };
